@@ -17,7 +17,7 @@
 #' }
 #'
 vcov.survstan <- function(object, all = FALSE, ...){
-  if(object$survreg == "yp"){
+  if(object$survreg == "yp" | object$survreg == "eh"){
     p <- 2*object$p
   }else{
     p <- object$p
@@ -107,7 +107,7 @@ estimates <- function(object, ...){
 #'
 coef.survstan <- function(object, ...){
   p <- object$p
-  if(object$survreg == "yp"){
+  if(object$survreg == "yp" | object$survreg == "eh"){
     p <- 2*p
   }
 
@@ -124,6 +124,7 @@ coef.survstan <- function(object, ...){
 #' Confidence intervals for the regression coefficients
 #'
 #' @aliases confint.survstan
+#' @importFrom stats confint
 #' @export
 #' @param object an object of the class survstan.
 #' @param level the confidence level required.
